==> webjars-play_2.13-3.1.0-M1-sources.jar: org/webjars/play/html/img.template.scala <==

package org.webjars.play.html

import _root_.play.twirl.api.TwirlFeatureImports._
import _root_.play.twirl.api.TwirlHelperImports._
import _root_.play.twirl.api.Html
import _root_.play.twirl.api.JavaScript
import _root_.play.twirl.api.Txt
import _root_.play.twirl.api.Xml

object img extends _root_.play.twirl.api.BaseScalaTemplate[play.twirl.api.HtmlFormat.Appendable,_root_.play.twirl.api.Format[play.twirl.api.HtmlFormat.Appendable]](play.twirl.api.HtmlFormat) with _root_.play.twirl.api.Template2[String,Map[String, String],play.twirl.api.HtmlFormat.Appendable] {

  /**/
  def apply/*1.2*/(url: String, params: Map[String, String] = Map.empty):play.twirl.api.HtmlFormat.Appendable = {
    _display_ {
      {


Seq[Any](format.raw/*2.1*/("""<img src=""""),_display_(/*2.12*/url),format.raw/*2.15*/("""" """),_display_(/*2.18*/for(p <- params) yield /*2.34*/ {_display_(Seq[Any](format.raw/*2.36*/(""" """),_display_(/*2.38*/{p._1}),format.raw/*2.44*/("""=""""),_display_(/*2.47*/{p._2}),format.raw/*2.53*/("""" """)))}),format.raw/*2.56*/(""">"""))
      }
    }
  }

  def render(url:String,params:Map[String, String]): play.twirl.api.HtmlFormat.Appendable = apply(url,params)

  def f:((String,Map[String, String]) => play.twirl.api.HtmlFormat.Appendable) = (url,params) => apply(url,params)

  def ref: this.type = this

}


              /*
                  -- GENERATED --
                  SOURCE: src/main/twirl/org/webjars/play/img.scala.html
                  HASH: cfcca6885b4eb77b2c37550a324cc97cf4f6b27e
                  MATRIX: 595->1|743->56|780->67|803->70|832->73|863->89|902->91|930->93|956->99|985->102|1011->108|1044->111
                  LINES: 14->1|19->2|19->2|19->2|19->2|19->2|19->2|19->2|19->2|19->2|19->2|19->2
                  -- GENERATED --
              */

==> webjars-play_3-3.1.0-M1-sources.jar: org/webjars/play/html/img.template.scala <==

package org.webjars.play.html

import _root_.play.twirl.api.TwirlFeatureImports.*
import _root_.play.twirl.api.TwirlHelperImports.*
import scala.language.adhocExtensions
import _root_.play.twirl.api.Html
import _root_.play.twirl.api.JavaScript
import _root_.play.twirl.api.Txt
import _root_.play.twirl.api.Xml

object img extends _root_.play.twirl.api.BaseScalaTemplate[play.twirl.api.HtmlFormat.Appendable,_root_.play.twirl.api.Format[play.twirl.api.HtmlFormat.Appendable]](play.twirl.api.HtmlFormat) with _root_.play.twirl.api.Template2[String,Map[String, String],play.twirl.api.HtmlFormat.Appendable] {

  /**/
  def apply/*1.2*/(url: String, params: Map[String, String] = Map.empty):play.twirl.api.HtmlFormat.Appendable = {
    _display_ {
      {


Seq[Any](format.raw/*2.1*/("""<img src=""""),_display_(/*2.12*/url),format.raw/*2.15*/("""" """),_display_(/*2.18*/for(p <- params) yield /*2.34*/ {_display_(Seq[Any](format.raw/*2.36*/(""" """),_display_(/*2.38*/{p._1}),format.raw/*2.44*/("""=""""),_display_(/*2.47*/{p._2}),format.raw/*2.53*/("""" """)))}),format.raw/*2.56*/(""">"""))
      }
    }
  }

  def render(url:String,params:Map[String, String]): play.twirl.api.HtmlFormat.Appendable = apply(url,params)

  def f:((String,Map[String, String]) => play.twirl.api.HtmlFormat.Appendable) = (url,params) => apply(url,params)

  def ref: this.type = this

}


              /*
                  -- GENERATED --
                  SOURCE: src/main/twirl/org/webjars/play/img.scala.html
                  HASH: 9ac139626cbc8e6f9b42cb537177c252a94d5e05
                  MATRIX: 633->1|781->56|818->67|841->70|870->73|901->89|940->91|968->93|994->99|1023->102|1049->108|1082->111
                  LINES: 15->1|20->2|20->2|20->2|20->2|20->2|20->2|20->2|20->2|20->2|20->2|20->2
                  -- GENERATED --
              */
